Procrustes Module
=================

.. automodule:: procrustes
   :members:
   
   .. autosummary::
      
      ShapeClassifier
      ShapeClassifier.fit
      ShapeClassifier.predict
      ShapeClassifier.predict_proba
      ShapeClassifier.procrustes_disparity
      ShapeClassifier.predict_class
